X-Git-Url: http://git.vanrenterghem.biz/git.ikiwiki.info.git/blobdiff_plain/296e5cb2fd3690e998b3824d54d317933c595873..3e791deb76b3cfd773f34d18cce551e29af46fc2:/IkiWiki/Plugin/search.pm

diff --git a/IkiWiki/Plugin/search.pm b/IkiWiki/Plugin/search.pm
index 78eb750b5..3f0b7c9ad 100644
--- a/IkiWiki/Plugin/search.pm
+++ b/IkiWiki/Plugin/search.pm
@@ -227,20 +227,21 @@ sub setupfiles () {
 			"database_dir .\n".
 			"template_dir ./templates\n");
 		
 		# Avoid omega interpreting anything in the misctemplate
 		# as an omegascript command.
-		my $misctemplate=IkiWiki::misctemplate(gettext("search"), "\0",
+		eval q{use IkiWiki::CGI};
+		my $template=IkiWiki::cgitemplate(undef, gettext("search"), "\0",
 			searchform => "", # avoid showing the small search form
 		);
 		eval q{use HTML::Entities};
 		error $@ if $@;
-		$misctemplate=encode_entities($misctemplate, '\$');
+		$template=encode_entities($template, '\$');
 
 		my $querytemplate=readfile(IkiWiki::template_file("searchquery.tmpl"));
-		$misctemplate=~s/\0/$querytemplate/;
+		$template=~s/\0/$querytemplate/;
 
 		writefile("query", $config{wikistatedir}."/xapian/templates",
-			$misctemplate);
+			$template);
 		$setup=1;
 	}
 }
@@ -227,20 +227,21 @@ sub setupfiles () {
 			"template_dir ./templates\n");
 		
-		# Avoid omega interpreting anything in the misctemplate
+		# Avoid omega interpreting anything in the cgitemplate
 		# as an omegascript command.